/////////////////////////////////////////////////////////////////////////////
// Name:        main.h
// Purpose:     Main page of the Doxygen manual
// Author:      wxWidgets team
// RCS-ID:      $Id$
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

/**

@mainpage Documentation

@author Julian Smart, Robert Roebling, Vadim Zeitlin, Robin Dunn,
        Stefan Csomor, Francesco Montorsi, Bryan Petty, et al

@date July, 2013

@image html main_wxlogo.png

@section manual_user User Manual

@li @subpage page_introduction
@li @subpage page_copyright
@li @subpage page_utils
@li @subpage page_samples
@li @subpage page_libs
@li @subpage page_class_cat
@li @subpage page_topics
@li @subpage page_multiplatform
@li @subpage page_port

@section manual_reference Reference Manual

@li @subpage page_constants
@li @subpage page_translations
@li @subpage group_class
@li @subpage group_funcmacro

*/
